﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;

namespace InstarCameraInterface
{

    /// <summary>
    /// This class represents a set of connection details to the camera device and offers some methods to create frequently
    /// used pathes.
    /// </summary>
    public class InstarCameraConnectionDetail : InstarCameraClassBase
    {

        /// <summary>
        /// Creates a new instance of this class
        /// </summary>
        /// <param name="address"></param>
        /// <param name="port"></param>
        /// <param name="timeout"></param>
        /// <param name="username"></param>
        /// <param name="password"></param>
        public InstarCameraConnectionDetail(InstarCamera camera, string address, int port, int timeout, string username, string password) : base(camera)
        {

            // Output a short debug message
            String msg = String.Format("InstarCameraConnectionDetail: address={0}; port={1}; timeout={2}; username={3}; password={4}", address, port,timeout,username,password );
            System.Diagnostics.Debug.WriteLine(msg);

            //TODO: URI richtig implementieren
            Uri u = new Uri(address);

            System.UriBuilder ub = new UriBuilder(u.Scheme, u.Host, port);
            this.CamAddressUri = ub.Uri;


            this.Address = address;
            this.Port = port;
            this.Timeout = timeout;
            this.Username = username;
            this.Password = password;
        
        }

        /// <summary>
        /// This URI represents the connection path to the camera.
        /// </summary>
        private Uri CamAddressUri { get; set; }

        /// <summary>
        /// The address to connect to the camera.
        /// </summary>
        public string Address { get; private set; }

        /// <summary>
        /// The port to connect to the camera.
        /// </summary>
        public int Port { get; private set; }

        /// <summary>
        /// The timeout intervall in ms for all commands sent to the camera device.
        /// </summary>
        public int Timeout { get; private set; }

        /// <summary>
        /// an username of an administrative account on the camera device
        /// </summary>
        public string Username { get; private set; }

        /// <summary>
        /// The according password to the administrative username
        /// </summary>
        public string Password { get; private set; }

        /// <summary>
        /// Returns the full address and port of the camera device.
        /// </summary>
        /// <returns></returns>
        public string FullCameraAddress()
        {
            return String.Format(@"{0}:{1}/", this.Address, this.Port);
        }

        /// <summary>
        /// Creates a path to a file hosted by the camera device containing the camer address, its port, the demanded filename and credentails.
        /// </summary>
        /// <param name="filename"></param>
        /// <returns></returns>
        public string FullCameraAddressWithCredentials(string filename)
        {
            return String.Format("{0}{1}?user={2}&pwd={3}",
                                    this.FullCameraAddress(),
                                    filename,
                                    this.Username,
                                    this.Password);

        }
    }
}
