﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using System.Net;

namespace InstarCameraInterface
{

    /// <summary>
    /// read-access to the camera-logfiles
    /// </summary>
    public class InstarCameraLogfile : InstarCameraClassBase 
    {
        /// <summary>
        /// creates a new instance of this class
        /// </summary>
        /// <param name="camera"></param>
        public InstarCameraLogfile(InstarCamera camera) : base(camera) {   }

        /// <summary>
        /// Returns the log entries stored in the camera device.
        /// </summary>
        /// <returns></returns>
        public InstarCameraLogfileEntry[] GetEntries() 
        {

            // define the camera file containing the log entries and load them
            InstarCameraVarDeclarationList logConfigFile = new InstarCameraVarDeclarationList(this.Camera, "get_log.cgi", true);
            
            // get the one and only entry from the config-file
            String mergedConfigFileEntries = logConfigFile.GetValueByName("log_text").PropertyValue;

            // free memory
            logConfigFile.Dispose();

            // split config file entry into lines
            String[] ConfigFileStringEntries = mergedConfigFileEntries.Split(new string[] { "\\n" }, StringSplitOptions.RemoveEmptyEntries);

            // free memory
            mergedConfigFileEntries = null;




            /*
             * Example for a config file
             * 
             *   var log_text='
             *   Tue, 2011-10-04 04:52:53   admin          85.183.29.153     access\n
             *   Tue, 2011-10-04 05:15:29   admin          85.183.29.153     access\n
             *   Tue, 2011-10-04 12:39:56   admin          141.82.61.249     access\n
             *   ';
             */

            // This list will store all entries from the cameras' config file
            List<InstarCameraLogfileEntry> configFileEntries = new List<InstarCameraLogfileEntry>();

            // reg expression to parse the single config-file entries.
            String RegEx = @"(?<Wochentag>[\w]{3}),[\s]*(?<Jahr>[\d]{4})-(?<Monat>[\d]{2})-(?<Tag>[\d]{2})[\s]*(?<Stunde>[\d]{2}):(?<Minute>[\d]{2}):(?<Sekunde>[\d]{2})[\s]*(?<User>.*)[\s]{2,}(?<ip1>[\d]{1,3}).(?<ip2>[\d]{1,3}).(?<ip3>[\d]{1,3}).(?<ip4>[\d]{1,3})[\s]{1,}(?<type>.*)";
           
            // iterate through all lines in the config file
            foreach (String line in ConfigFileStringEntries)
            {
                // test if this line can be parsed
                if (Regex.IsMatch(line, RegEx))
                {
                    // yes, the line can be parsed
                    // run the parser and store the results
                    Match match = Regex.Match(line, RegEx);

                    // use the parsed values to create a time-object representing the event-time
                    DateTime time = new DateTime(int.Parse(match.Groups["Jahr"].Value),
                                                 int.Parse(match.Groups["Monat"].Value),
                                                 int.Parse(match.Groups["Tag"].Value),
                                                 int.Parse(match.Groups["Stunde"].Value),
                                                 int.Parse(match.Groups["Minute"].Value),
                                                 int.Parse(match.Groups["Sekunde"].Value));

                    // fetch the username from the parsed values
                    String Username = match.Groups["User"].Value;

                    // use the parsed values to create a ip-object 
                    IPAddress IP = IPAddress.Parse(String.Format("{0}.{1}.{2}.{3}", int.Parse(match.Groups["ip1"].Value),
                                                                                    int.Parse(match.Groups["ip2"].Value),
                                                                                    int.Parse(match.Groups["ip3"].Value),
                                                                                    int.Parse(match.Groups["ip4"].Value)));

                    // fetch the access type from the parsed values
                    String type = match.Groups["type"].Value;

                    // create a logfile-entry-object and save it
                    configFileEntries.Add(new InstarCameraLogfileEntry(this.Camera, time, IP, Username, type));

                }
            }

            // return all log-file-entries as array
            return configFileEntries.ToArray();

        
        }

      



    }
}
