﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;

namespace InstarCameraInterface
{
    public class InstarCameraMovement : InstarCameraClassBase 
    {
        public enum CameraMovementEnum
        {
            

            StartUp=0, 
            StopUp=1,
            StartDown=2,
            StopDown=3,
            StartLeft=4,
            StopLeft = 5,
            StartRight=6,
            StopRight=7,

            HomePos = 25,
            StartVerticalPatrol=26,
            StopVerticalPatrol=27,
            StartHorizonPatrol = 28,
            StopHorizonPatrol = 29
        }

        public enum InstarCameraPositionEnum
        {
            Pos01 = 31,
            Pos02 = 33,
            Pos03 = 35,
            Pos04 = 37,
            Pos05 = 39,
            Pos06 = 41,
            Pos07 = 43,
            Pos08 = 45,
            Pos09 = 47,
            pos10 = 49,
            Pos11 = 51,
            Pos12 = 53,
            Pos13 = 55,
            Pos14 = 57,
            Pos15 = 59
        }

        public InstarCameraMovement(InstarCamera camera) :base(camera) {}

       

        /// <summary>
        /// Saves the current camera position.
        /// </summary>
        /// <param name="position"></param>
        /// <returns></returns>
        public Boolean SaveCurrentPosition(InstarCameraPositionEnum position)
        {
            String filename = "decoder_control.cgi";
            String parameter = String.Format("command={0}", (((int)position - 1)));
            return InstarCameraHelper.ExecuteHttpCommand(filename, parameter, this.Camera);
        }

        public Boolean MoveToPosition(InstarCameraPositionEnum position) 
        {
            String filename = "decoder_control.cgi";
            String parameter = String.Format("command={0}", ((int)position));
            return InstarCameraHelper.ExecuteHttpCommand(filename, parameter, this.Camera);
        }


        public bool MoveTo(CameraMovementEnum position, string AppendToParameterlist = "") 
        {

           String parameter = string.Format("command={0}&{1}", (int)position, AppendToParameterlist);
            return InstarCameraHelper.ExecuteHttpCommand("decoder_control.cgi", parameter, this.Camera);
         
        }

        public bool MoveToHomePos() { return this.MoveTo(CameraMovementEnum.HomePos); }

        private bool Move(CameraMovementEnum position, bool OnlyOneStep) 
        {
            String AppendPrm = "";
            if (!OnlyOneStep) AppendPrm += "onestep";
            return MoveTo(position, AppendPrm);

        }

        public bool SingleStepUp() { return this.Move(CameraMovementEnum.StartUp, true);  }

        public bool SingleStepDown() { return this.Move(CameraMovementEnum.StartDown , true); }

        public bool SingleStepLeft() { return this.Move(CameraMovementEnum.StartLeft , true); }

        public bool SingleStepRight() { return this.Move(CameraMovementEnum.StartRight, true); }


        public bool StartMoveUp() { return this.Move(CameraMovementEnum.StartUp, false); }
        public bool StopMoveUp() { return this.Move(CameraMovementEnum.StopUp, false); }

        public bool StartMoveDown() { return this.Move(CameraMovementEnum.StartDown, false); }
        public bool StopMoveDown() { return this.Move(CameraMovementEnum.StopDown, false); }

        public bool StartMoveLeft() { return this.Move(CameraMovementEnum.StartLeft, false); }
        public bool StopMoveLeft() { return this.Move(CameraMovementEnum.StopLeft, false); }

        public bool StartMoveRight() { return this.Move(CameraMovementEnum.StartRight, false); }
        public bool StopMoveRight() { return this.Move(CameraMovementEnum.StopRight, false); }

    
    }

}
