﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;

namespace InstarCameraInterface
{
    

    public class InstarCameraUserList : InstarCameraClassBase 
    {

        const int MaxUserAccountCount = 8;

        public InstarCameraUserList(InstarCamera camera) :base(camera) { 
            
            this.Load();
        
        }


        private void Load()
        {

            for (int i = 1; i <= 8; i++)
            {
                String varName_User = string.Format("user{0}_name", i.ToString());
                String varName_Pwd = string.Format("user{0}_pwd", i.ToString());
                String varName_pri = string.Format("user{0}_pri", i.ToString());

                InstarCameraUser user = new InstarCameraUser();
                user.Username = this.Camera.Configuration.GetValueByName(varName_User).PropertyValue;
                user.Password = this.Camera.Configuration.GetValueByName(varName_Pwd).PropertyValue;

                switch (this.Camera.Configuration.GetValueByName(varName_pri).PropertyValue)
                {
                    case "0": user.Group = InstarCameraUser.GroupEnum.Visitor; break;
                    case "1": user.Group = InstarCameraUser.GroupEnum.User; break;
                    case "2": user.Group = InstarCameraUser.GroupEnum.Administrator; break;
                }

                if (String.IsNullOrEmpty(user.Username) && string.IsNullOrEmpty(user.Password)) continue;
                this.AllUsers.Add(user);


            }

        }

   
        private Boolean IsUserInList(String Username)
        {

            var X = from U in this.AllUsers where U.Username == Username select U;
            return (X.Count() > 0); 

        
        }

        private List<InstarCameraUser> AllUsers = new List<InstarCameraUser>();

        public Boolean Add(InstarCameraUser User) {

            // Kamera kann maximal 8 Benutzerkonten speichern
            // Wenn diese Grenze erreicht ist darf kein weiterer Benutzer hinzugefügt werden.
            if (this.AllUsers.Count == MaxUserAccountCount) return false;

            // Jeder Benutzername darf nur einmal vergeben werden - ausnahme leere Benutzerzeichenfolgen.
            if (!String.IsNullOrEmpty(User.Username) && this.IsUserInList(User.Username)) return false;

            // Benutzer speichern und Erfolgsmeldung zurückgeben.
            this.AllUsers.Add(User);
            return true;
        }



        public void Remove(InstarCameraUser User) { this.AllUsers.Remove(User); }

        public InstarCameraUser[] Users() { return this.AllUsers.ToArray(); }

        public void Refresh() { this.AllUsers.Clear(); this.Load(); }

        public InstarCameraUser this[String username]
        {
            get { 
                var X = from U in this.AllUsers where U.Username == username select U;
                if (X.Count() != 1) return null;
                return X.First();
            }                      
        }

        public int RemoveAllUserButCurrent()
        {
            int RemovedAccounts = 0;
            var victims = from U in this.AllUsers where U.Username != this.Camera.Connection.Username select U;
            
            foreach (InstarCameraUser U in victims.ToArray())
            { 
                this.Remove(U);
                RemovedAccounts++;
            }

            return RemovedAccounts;



        }

        /// <summary>
        /// Überträgt die Änderungen auf die Kamera.
        /// </summary>
        /// <returns></returns>
        public Boolean Save(Boolean RebootWhenChanged = false) 
        {
             /*
             * Aufruf zum setzen der Benutzerkonten:
             * http://192.168.0.150/set_users.cgi?user1=Username&pwd1=Password&pri1=2&....user8=&pwd8=&pri8=0
             * 
             * Info: Es müssen immer alle 8 Konten angegeben werden
             */

            // Adresse des Scripts das die Benutzerdaten setzen kann incl. der Authentifizierung
            String filename = "set_users.cgi";
            String parameter = "";

            // Aufruf durch anhängen der 8 Benutzerkonten vervollständigen.
            for (int UserNr =1; UserNr <= 8; UserNr++ )
            {
                InstarCameraUser User = new InstarCameraUser();
                if (UserNr <= this.AllUsers.Count) User = AllUsers[UserNr-1];
             
                parameter += String.Format(@"user{0}={1}&pwd{0}={2}&pri{0}={3}&", 
                    UserNr.ToString(), 
                    User.Username,
                    User.Password, 
                    (int)User.Group);
            }

            // Aufruf durchführen
            string Result = HttpHelper.GetContent(parameter, this.Camera.Connection.Timeout);

            // Bei Erfolg wird "Ok.\n" zurück gegeben.
            Boolean Success = InstarCameraHelper.ExecuteHttpCommand(filename, parameter, this.Camera); //Result.Contains("ok");

            // Wenn die Änderungen erfolgreich gespeichert wurden und der Benutzer einen 
            // Neustart der Kamera wünscht diesen durchführen.
            if (Success && RebootWhenChanged) this.Camera.Reboot();

            // Statusmeldung zurück geben
            return Success;
        }

    }
}
