﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;
using System.Collections.Generic;

namespace InstarCameraInterface
{
    public class InstarCameraVarDeclarationList : InstarCameraClassBase, IDisposable
    {


        public void Invalide() { this.AllValuesAreValid = false; }

        public Boolean AllValuesAreValid { get; private set; }

        public Boolean CanRead { get; private set; }


        public InstarCameraVarDeclatation  this[String name]
        {
            get { return this.GetValueByName(name); }
        }

        private Dictionary<String, InstarCameraVarDeclatation> CamProperties = new Dictionary<String, InstarCameraVarDeclatation>();

        private String SourceFile { get; set; }


        public InstarCameraVarDeclarationList(InstarCamera camera, String sourceFile, Boolean LoadValuesOnStartup = false)  : base(camera)
        { 
            
            this.SourceFile = sourceFile;
            if (LoadValuesOnStartup) this.Load();
        }

        public String[] GetPropertyNames() 
        {
            List<String> Keys = new List<string>();
            foreach (String Key in CamProperties.Keys) Keys.Add(Key);
            return Keys.ToArray();        
        }


        public InstarCameraVarDeclatation GetValueByName(String PropertyName) { 
            if (!this.AllValuesAreValid)this.Reload();
            return CamProperties[PropertyName]; 
        }

        internal void Load()
        {

            
            CamProperties.Clear();

            try
            { 
                // Create url to source file
                String Url = this.Camera.Connection.FullCameraAddressWithCredentials(this.SourceFile);

                // Receive content from source file
               String data = HttpHelper.GetContent(Url, this.Camera.Connection.Timeout);

                // for each line in received content
                foreach (String line in data.Split("\n".ToCharArray()))
                {
                    // If line does not declate a varible continue
                    if (!line.StartsWith("var ")) continue;
                
                    // Create a new VarDeclaration-Object and append it to list
                    InstarCameraVarDeclatation Prop = new InstarCameraVarDeclatation(line);
                    this.CamProperties.Add(Prop.PropertyName, Prop);                

                }
                this.AllValuesAreValid = true;
                this.CanRead = true;
                }
            catch (Exception ex) 
            {
                this.CanRead = false;
            }
            
        }

        public void Reload() { this.Load(); }



        public void Dispose()
        {
            CamProperties.Clear();
            CamProperties = null;

            this.SourceFile = null;

        }

    }
}
