﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;

namespace InstarCameraInterface
{

    /// <summary>
    /// This class offers some methods for easy accessing of http content.
    /// </summary>
    internal static class HttpHelper
    {

        /// <summary>
        /// Returns the content of a web ressource as string
        /// </summary>
        /// <param name="Url">Address of the web ressource</param>
        /// <param name="timeout"></param>
        /// <returns></returns>
        public static String GetContent(String Url, int timeout)
        {

            // Output a short debug message
            String msg = String.Format("GetContent: Url={0}; timeout{1}", Url, timeout);
            System.Diagnostics.Debug.WriteLine(msg);


            // Check the validity of the arguments
            System.Diagnostics.Debug.Assert(timeout > 0, "Error: Timeout hast to be bigger than zero.");
            System.Diagnostics.Debug.Assert(!String.IsNullOrEmpty(Url), "Error: Url mustn't be empty.");
            


            // Create a stream to the ressource
            System.IO.Stream StreamToRessource = HttpHelper.GetContentStream(Url, timeout);

            // Create a streamreader for the stream to the ressource
            System.IO.StreamReader reader = new System.IO.StreamReader(StreamToRessource);

            // Read the complete content from the ressource
            String data = reader.ReadToEnd();

            // Close reader and stream
            reader.Close();
            reader.Dispose();
        
            return data;
        }

        /// <summary>
        /// Returns the content of a web ressource as stream
        /// </summary>
        /// <param name="Url">Address of the web ressource</param>
        /// <param name="timeout"></param>
        /// <returns></returns>
        public static System.IO.Stream GetContentStream(String Url, int timeout)
        {
            // Output a short debug message
            String msg = String.Format("GetContentStream: Url={0}; timeout{1}", Url, timeout);
            System.Diagnostics.Debug.WriteLine(msg);


            // Check the validity of the arguments
            System.Diagnostics.Debug.Assert(timeout > 0, "Error: Timeout hast to be bigger than zero.");
            System.Diagnostics.Debug.Assert(!String.IsNullOrEmpty(Url), "Error: Url mustn't be empty.");

            // Create a new WebRequest to the Url
            System.Net.HttpWebRequest WebReq = (System.Net.HttpWebRequest)System.Net.HttpWebRequest.Create(Url);
            WebReq.Timeout = timeout;

            // Try to get a response from the ressource
            var Response = WebReq.GetResponse();
            
            // Save a reference to the stream of the server response
            System.IO.Stream stream = Response.GetResponseStream();
            WebReq = null;

            // return the stream
            return stream;
        
        }

        /// <summary>
        /// Returns the content of a web ressource as image
        /// </summary>
        /// <param name="Url">Address of the web ressource</param>
        /// <param name="timeout"></param>
        /// <returns></returns>
        public static System.Drawing.Image GetContentImage(String Url, int timeout)
        {

            // Output a short debug message
            String msg = String.Format("GetContentImage: Url={0}; timeout{1}", Url, timeout);
            System.Diagnostics.Debug.WriteLine(msg);

            // Check the validity of the arguments
            System.Diagnostics.Debug.Assert(timeout > 0, "Error: Timeout hast to be bigger than zero.");
            System.Diagnostics.Debug.Assert(!String.IsNullOrEmpty(Url), "Error: Url mustn't be empty.");


            // Get the stream representing the ressource
            System.IO.Stream ContentStream = HttpHelper.GetContentStream(Url, timeout);
            
            // Create an image object from the stream
            System.Drawing.Image img = System.Drawing.Image.FromStream(ContentStream);

            // Close stream and free ressources
            ContentStream.Close();
            ContentStream.Dispose();
            ContentStream = null;

            // return the image
            return img;

        }
    }
}
