﻿/*
 * Instar Camera Interface
 * 
 * Hosted on codeplex: http://ici.codeplex.com
 * Camera devices: http://www.instar.de/
 * Author: Sebastian Kraemer, Sebastian.Kraemer@swKraemer.de
 *
 */
using System;

namespace InstarCameraInterface
{
    /// <summary>
    /// This class offers some methods which are frequentliy used fpr communication with instar camera devices.
    /// </summary>
    internal static class InstarCameraHelper
    {

        /// <summary>
        /// Sends a request to the given filename, attaches the parameters and returns true if the camera device answers with "ok."
        /// </summary>
        /// <param name="filename"></param>
        /// <param name="parameter"></param>
        /// <param name="camera"></param>
        /// <returns></returns>
        public static bool ExecuteHttpCommand(String filename, string parameter, InstarCamera camera)
        {
            // Output a short debug message
            String msg = String.Format("ExecuteHttpCommand: filename={0}; parameter{1}", filename, parameter);
            System.Diagnostics.Debug.WriteLine(msg);


            // Check the validity of the arguments
            System.Diagnostics.Debug.Assert(camera != null, "Error: no camera object set.");
            System.Diagnostics.Debug.Assert(!String.IsNullOrEmpty(filename), "Error: filename mustn't be empty.");

            // Fetch the address of the camera containing the credentials of the user
            String AddrWithCredentials = camera.Connection.FullCameraAddressWithCredentials(filename);

            // Concatinate address and parameters
            String url = String.Format("{0}&{1}", AddrWithCredentials, parameter);

            // execute request
            String result = HttpHelper.GetContent(url, camera.Connection.Timeout);

            // return if action was successfully
            return result.Contains("ok.");
        
        
        }

    }
}
