﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using InstarCameraInterface;

namespace InstarCameraTester
{
    public partial class Form1 : Form
    {

        private InstarCameraInterface.InstarCamera Cam;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {

            try
            {

                KeyValueFile CamInfoFile = new KeyValueFile(@"C:\CamInfoFile.txt");

                if (!CamInfoFile.Exists())
                {
                    String msg = String.Format("Unable to open configuration file {0}\n Use the following parameters to specify the camera parameters: address, port, username, [password]\n ParameterName:=ParameterValue", CamInfoFile.Filename);
                    MessageBox.Show(msg, "Configuration file missing", MessageBoxButtons.OK, MessageBoxIcon.Information);
                    Application.Exit();
                
                }


                String CameraAddress = CamInfoFile.GetValueByName("address");// "http://192.168.0.152";
                short CameraPort = short.Parse(CamInfoFile.GetValueByName("port")); //80;
                String Username = CamInfoFile.GetValueByName("username");  //"admin";
                String Password = CamInfoFile.GetValueByName("password");
                if (String.IsNullOrEmpty(Password)) Password = Microsoft.VisualBasic.Interaction.InputBox(String.Format("Please enter password for {0} to connect to {1}:", Username, CameraAddress));

                Cam = new InstarCameraInterface.InstarCamera(CameraAddress, CameraPort, Username, Password);


                if (Cam.CameraControl.CanRead)
                { 
                    this.tbBrightness.Value = Cam.CameraControl.Brightness;
                    this.tbContrast.Value = Cam.CameraControl.Contrast;
                    this.cmbMode.SelectedIndex = (int)Cam.CameraControl.Mode;
                    this.Text = String.Format("Camera device: {0}", Cam.Alias);
                }


               

                tmrUpdateSnapshot.Enabled = true;
            }
            catch (Exception ex) 
            {
                MessageBox.Show(ex.Message);
            }
        }


        private void btnMoveLeft_MouseDown(object sender, MouseEventArgs e) { Cam.Movement.StartMoveLeft(); }

        private void btnMoveLeft_MouseUp(object sender, MouseEventArgs e)   { Cam.Movement.StopMoveLeft();}

        private void btnMoveDown_MouseUp(object sender, MouseEventArgs e)   { Cam.Movement.StopMoveDown(); }

        private void btnMoveDown_MouseDown(object sender, MouseEventArgs e) { Cam.Movement.StartMoveDown(); }

        private void btnMoveRight_MouseUp(object sender, MouseEventArgs e)  { Cam.Movement.StopMoveRight(); }

        private void btnMoveRight_MouseDown(object sender, MouseEventArgs e) { Cam.Movement.StartMoveRight(); }

        private void btnMoveUp_MouseUp(object sender, MouseEventArgs e) { Cam.Movement.StopMoveUp(); }

        private void btnMoveUp_MouseDown(object sender, MouseEventArgs e) { Cam.Movement.StartMoveUp(); }

        private void tmrUpdateSnapshot_Tick(object sender, EventArgs e) { 
            
            tmrUpdateSnapshot.Enabled = false;
            try
            {

                // Nachrichtenkette abarbeiten
                Application.DoEvents();

                // Text der in das Bild eingefügt werden soll
                Cam.Snapshot.TextInImage = String.Format("{0} - {1}", DateTime.Now.ToLongDateString(), DateTime.Now.ToLongTimeString());

                // Bild von der Kamera abrufen und anzeigen
                this.picSnapshot.Image = Cam.Snapshot.Create();

            }
            catch (Exception ex)  {
                System.Diagnostics.Debug.WriteLine(ex.Message);
            }
            finally { tmrUpdateSnapshot.Enabled = true; }

            
        }

        private void tabControl1_SelectedIndexChanged(object sender, EventArgs e) { tmrUpdateSnapshot.Enabled = (tabControl1.SelectedTab == tpMovement); }

        private void tbBrightness_Scroll(object sender, EventArgs e) {Cam.CameraControl.Brightness = (int)tbBrightness.Value; }

        private void trackBar1_Scroll(object sender, EventArgs e) { Cam.CameraControl.Contrast = tbContrast.Value; }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e) {
            Cam.CameraControl.Mode = (InstarCameraInterface.InstarCameraControl.InstarCameraModeEnum)cmbMode.SelectedIndex;
        }

        private void button1_Click(object sender, EventArgs e)
        {

            int UserCount = Cam.Users.Users().Length;

            MessageBox.Show(String.Format("Count of registered users: {0}", UserCount));
        }

        private void btnShowCredentials_Click(object sender, EventArgs e)
        {

            String output = "Registered users: \n\n";

            foreach (InstarCameraInterface.InstarCameraUser U in Cam.Users.Users())
                output += String.Format("  - {0} ({1}): {2} \n", U.Username, U.Group.ToString(), U.Password);
            

            MessageBox.Show(output, "Users", MessageBoxButtons.OK, MessageBoxIcon.Information);


        }

        private void btnRemoveAllUsersButCurrent_Click(object sender, EventArgs e)
        {
            int RemovedUsers = Cam.Users.RemoveAllUserButCurrent();
            Cam.Users.Save();

            String msg = string.Format("Count of removed users: {0}", RemovedUsers);

            MessageBox.Show(msg, "Users", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void btnSaveThisPos_Click(object sender, EventArgs e)
        {
            Cam.Movement.SaveCurrentPosition(InstarCameraMovement.InstarCameraPositionEnum.Pos01);
        }

        private void btnLoadPos_Click(object sender, EventArgs e)
        {
            Cam.Movement.MoveToPosition(InstarCameraMovement.InstarCameraPositionEnum.Pos01);
        }

       

    

       

     

        

    }
}